@@ -21,8 +21,8 @@ logger = logging.getLogger(__name__)
 def main():
     try:
         server = config.Config().get_musicbrainz_server()
-    except KeyError, e:
-        sys.stderr.write('whipper: %s\n' % e.message)
+    except KeyError as e:
+        sys.stderr.write('whipper: %s\n' % str(e))
         sys.exit()
 
     musicbrainzngs.set_hostname(server)
@@ -30,24 +30,24 @@ def main():
     distributions, _ = pkg_resources.working_set.find_plugins(
         pkg_resources.Environment([directory.data_path('plugins')])
     )
-    map(pkg_resources.working_set.add, distributions)
+    list(map(pkg_resources.working_set.add, distributions))
     try:
         cmd = Whipper(sys.argv[1:], os.path.basename(sys.argv[0]), None)
         ret = cmd.do()
-    except SystemError, e:
+    except SystemError as e:
         sys.stderr.write('whipper: error: %s\n' % e)
-        if (type(e) is common.EjectError and
+        if (isinstance(e, common.EjectError) and
                 cmd.options.eject in ('failure', 'always')):
             eject_device(e.device)
         return 255
-    except RuntimeError, e:
+    except RuntimeError as e:
         print(e)
         return 1
     except KeyboardInterrupt:
         return 2
-    except ImportError, e:
+    except ImportError as e:
         raise
-    except task.TaskException, e:
+    except task.TaskException as e:
         if isinstance(e.exception, ImportError):
             raise ImportError(e.exception)
         elif isinstance(e.exception, common.MissingDependencyException):
@@ -105,5 +105,5 @@ You can get help on subcommands by using the -h option to the subcommand.
             self.parser.print_help()
             sys.exit(0)
         if self.options.version:
-            print "whipper %s" % whipper.__version__
+            print("whipper %s" % whipper.__version__)
             sys.exit(0)
