@@ -23,6 +23,7 @@ import os
 import os.path
 import math
 import subprocess
+import unicodedata
 
 from whipper.extern import asyncsub
 
@@ -153,6 +154,20 @@ class MissingFrames(Exception):
     pass
 
 
+def truncate_filename(path):
+    """
+    Truncate filename to the max. len. allowed by the path's filesystem
+    Hopefully it handles Unicode strings correctly
+    """
+    p, f = os.path.split(os.path.normpath(path))
+    f, e = os.path.splitext(f)
+    fn_lim = os.pathconf(p, 'PC_NAME_MAX')  # max.filename length in bytes
+    f_max = fn_lim - len(e.encode('utf-8'))
+    f = unicodedata.normalize('NFC', f)
+    f_trunc = unicode(f.encode('utf-8')[:f_max], 'utf-8', errors='ignore')
+    return os.path.join(p, f_trunc + e)
+
+
 def shrinkPath(path):
     """
     Shrink a full path to a shorter version.
@@ -197,7 +212,7 @@ def getRealPath(refPath, filePath):
 
     @type  filePath: unicode
     """
-    assert type(filePath) is unicode, "%r is not unicode" % filePath
+    assert isinstance(filePath, unicode), "%r is not unicode" % filePath
 
     if os.path.exists(filePath):
         return filePath
@@ -298,7 +313,7 @@ class VersionGetter(object):
             vre = self._regexp.search(output)
             if vre:
                 version = self._expander % vre.groupdict()
-        except OSError, e:
+        except OSError as e:
             import errno
             if e.errno == errno.ENOENT:
                 raise MissingDependencyException(self._dep)
